==> malaya_speech-0.0.1.4.1-py3-none-any.whl: malaya_speech/config/universal_melgan.py <==
config = {
    'sampling_rate': 22050,
    'hop_size': 256,
    'melgan_generator_params': {
        'out_channels': 1,
        'kernel_size': 7,
        'filters': 2048,
        'upsample_scales': [8, 8, 4],
        'stack_kernel_size': 3,
        'stacks': 4,
        'is_weight_norm': False,
    },
    'melgan_waveform_discriminator_params': {
        'out_channels': 1,
        'scales': 3,
        'downsample_pooling': 'AveragePooling1D',
        'downsample_pooling_params': {'pool_size': 4, 'strides': 4},
        'kernel_sizes': [5, 3],
        'filters': 16,
        'max_downsample_filters': 512,
        'downsample_scales': [4, 4, 2],
        'nonlinear_activation': 'LeakyReLU',
        'nonlinear_activation_params': {'alpha': 0.2},
        'is_weight_norm': False,
    },
    'melgan_stft_discriminator_params': {
        'fft_length': 1024,
        'frame_length': 1024,
        'frame_step': 256,
        'out_channels': 1,
        'scales': 3,
        'downsample_pooling': 'AveragePooling2D',
        'downsample_pooling_params': {'pool_size': 4, 'strides': 4},
        'kernel_sizes': [5, 3],
        'filters': 32,
        'max_downsample_filters': 32,
        'downsample_scales': [1, 1, 1],
        'nonlinear_activation': 'LeakyReLU',
        'nonlinear_activation_params': {'alpha': 0.2},
        'is_weight_norm': False,
    },
    'lambda_feat_match': 10.0,
    'batch_size': 16,
    'batch_max_steps': 8192,
    'batch_max_steps_valid': 81920,
    'remove_short_samples': True,
    'allow_cache': True,
    'is_shuffle': True,
    'generator_optimizer_params': {'lr': 0.0001, 'beta_1': 0.5, 'beta_2': 0.9},
    'discriminator_optimizer_params': {
        'lr': 0.0001,
        'beta_1': 0.5,
        'beta_2': 0.9,
    },
    'train_max_steps': 4000000,
    'save_interval_steps': 3,
    'eval_interval_steps': 2,
    'log_interval_steps': 1,
    'discriminator_train_start_steps': 0,
    'num_save_intermediate_results': 1,
}

==> malaya_speech-1.2-py3-none-any.whl: malaya_speech/config/universal_melgan.py <==
config = {
    'sampling_rate': 22050,
    'hop_size': 256,
    'melgan_generator_params': {
        'out_channels': 1,
        'kernel_size': 7,
        'filters': 2048,
        'upsample_scales': [8, 8, 4],
        'stack_kernel_size': 3,
        'stacks': 4,
        'is_weight_norm': False,
    },
    'melgan_waveform_discriminator_params': {
        'out_channels': 1,
        'scales': 3,
        'downsample_pooling': 'AveragePooling1D',
        'downsample_pooling_params': {'pool_size': 4, 'strides': 4},
        'kernel_sizes': [5, 3],
        'filters': 16,
        'max_downsample_filters': 512,
        'downsample_scales': [4, 4, 2],
        'nonlinear_activation': 'LeakyReLU',
        'nonlinear_activation_params': {'alpha': 0.2},
        'is_weight_norm': False,
    },
    'melgan_stft_discriminator_params': {
        'fft_length': [1024, 2048, 512],
        'frame_length': [600, 1200, 240],
        'frame_step': [120, 240, 50],
        'out_channels': 1,
        'scales': 3,
        'downsample_pooling': 'AveragePooling2D',
        'downsample_pooling_params': {'pool_size': 4, 'strides': 4},
        'kernel_sizes': [5, 3],
        'filters': 32,
        'max_downsample_filters': 32,
        'downsample_scales': [1, 1, 1],
        'nonlinear_activation': 'LeakyReLU',
        'nonlinear_activation_params': {'alpha': 0.2},
        'is_weight_norm': False,
    },
    'lambda_feat_match': 10.0,
    'batch_size': 16,
    'batch_max_steps': 8192,
    'batch_max_steps_valid': 81920,
    'remove_short_samples': True,
    'allow_cache': True,
    'is_shuffle': True,
    'generator_optimizer_params': {'lr': 0.0001, 'beta_1': 0.5, 'beta_2': 0.9},
    'discriminator_optimizer_params': {
        'lr': 0.0001,
        'beta_1': 0.5,
        'beta_2': 0.9,
    },
    'train_max_steps': 4000000,
    'save_interval_steps': 3,
    'eval_interval_steps': 2,
    'log_interval_steps': 1,
    'discriminator_train_start_steps': 0,
    'num_save_intermediate_results': 1,
}
